@@ -1,5 +1,5 @@
 // Shortwave - song.rs
-// Copyright (C) 2020  Felix Häcker <haeckerfelix@gnome.org>
+// Copyright (C) 2021  Felix Häcker <haeckerfelix@gnome.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ pub struct Song {
 
 impl Song {
     pub fn new(title: &str, path: PathBuf, duration: Duration) -> Self {
-        debug!("New song: \"{}\", {:?}", title, path);
+        debug!("Created new song: \"{}\", {:?}", title, path);
 
         Self {
             title: title.to_string(),
